# -*- mode: python; coding: utf-8 -*-
#
# Pigment Python binding image border example
#
# Copyright © 2006, 2007, 2008 Fluendo Embedded S.L.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
#
# Author: Loïc Molinari <loic@fluendo.com>

import sys, pgm, gobject

# Terminate the mainloop on a delete event
def on_delete(viewport, event):
    pgm.main_quit()

# Key press handler
def on_key_press(viewport, event, img):
    if event.keyval == pgm.keysyms.a:
        img.border_width -= 1.0
    if event.keyval == pgm.keysyms.z:
        img.border_width += 1.0
    if event.keyval == pgm.keysyms.q:
        img.border_outer_a -= 5
        img.border_inner_a -= 5
    if event.keyval == pgm.keysyms.s:
        img.border_outer_a += 5
        img.border_inner_a += 5
    if event.keyval == pgm.keysyms.w:
        img.layout = pgm.IMAGE_SCALED
    if event.keyval == pgm.keysyms.x:
        img.layout = pgm.IMAGE_FILLED
    if event.keyval == pgm.keysyms.c:
        img.layout = pgm.IMAGE_ZOOMED
    if event.keyval == pgm.keysyms.Escape:
        pgm.main_quit()

# Entry point
def main(args):
    # OpenGL viewport creation
    gl = pgm.viewport_factory_make('opengl')
    gl.connect('delete-event', on_delete)
    gl.title = 'Image border'

    # Canvas creation
    cvs = pgm.Canvas()
    cvs.size = (800, 600)
    gl.set_canvas(cvs)

    # Image creation
    img = pgm.Image()
    img.set_from_file('examples/pictures/meiko.jpg')
    img.size = (600, 400)
    img.position = (100, 100, 0)
    img.bg_color = (0, 0, 255, 255)
    cvs.add(pgm.DRAWABLE_MIDDLE, img)
    img.border_width = 10.0
    img.border_inner_color = (255, 255, 255, 200)
    img.border_outer_color = (255, 255, 255, 200)
    gl.connect('key-press-event', on_key_press, img)

    # Print exaplanations on the key bindings
    print 'Pigment image border example:'
    print ''
    print 'a:     decrease border width'
    print 'z:     increase border width'
    print 'q:     decrease border opacity'
    print 's:     increase border opacity'
    print 'w:     change image layout to SCALED'
    print 'x:     change image layout to FILLED'
    print 'c:     change image layout to ZOOMED'
    print 'Echap: Quit the application'

    # Show the objects and start the main loop
    img.show()
    gl.show()
    pgm.main()

if __name__ == '__main__':
    sys.exit(main(sys.argv[1:]))
